<?xml version="1.0"?>
<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:output method="xml" indent="yes"/>
	<xsl:strip-space elements="*"/>
	<xsl:param name="linkElementName"/>

	<xsl:template match="GMT-LINK | DELTA-LINK">
		<xsl:element name="{$linkElementName}">
			<xsl:attribute name="link-id">%LINK-ID%</xsl:attribute>
		</xsl:element>
		<!--<delta-link link-id="%LINK-ID%"/>-->
	</xsl:template>
	<xsl:template match="GMT-LINK_EXT | DELTA-LINK_EXT">
		<xsl:element name="{$linkElementName}">
			<xsl:attribute name="link-id">%LINK-ID%</xsl:attribute>
			<xsl:attribute name="comment">%INPUT% %TEXT%</xsl:attribute>
			<xsl:attribute name="created-at">%DATE%, %TIME%</xsl:attribute>
			<xsl:attribute name="created-by">%USER%</xsl:attribute>
		</xsl:element>
		<!--<delta-link link-id="%LINK-ID%" comment="%INPUT% %TEXT%" created-at="%DATE%, %TIME%" created-by="%USER%"/>-->
	</xsl:template>

	<xsl:template match="macro">
		<xsl:variable name="specialAttrValues">
			<xsl:apply-templates select="*" mode="_macro"/>
		</xsl:variable>
		<xsl:copy>
			<xsl:attribute name="hasLink"><xsl:value-of select="boolean(contains($specialAttrValues,'%LINK-ID%'))"/></xsl:attribute>
			<xsl:attribute name="takesSelection"><xsl:value-of select="boolean(contains($specialAttrValues,'%TEXT%'))"/></xsl:attribute>
			<xsl:attribute name="inputRequired"><xsl:value-of select="boolean(contains($specialAttrValues,'%INPUT%'))"/></xsl:attribute>
			<xsl:apply-templates select="*|@*"/>
		</xsl:copy>
	</xsl:template>
	<xsl:template match="GMT-LINK | DELTA-LINK" mode="_macro">
		<xsl:text>%LINK-ID%</xsl:text>
	</xsl:template>
	<xsl:template match="GMT-LINK_EXT | DELTA-LINK_EXT" mode="_macro">
		<xsl:text>%LINK-ID%%INPUT%%TEXT%</xsl:text>
	</xsl:template>
	<xsl:template match="attribute-ref" mode="_macro"><xsl:value-of select="@value"/><xsl:value-of select="@default-value"/></xsl:template>
	<xsl:template match="constant-def" mode="_macro"><xsl:value-of select="@value"/></xsl:template>
	<xsl:template match="text-node" mode="_macro"><xsl:value-of select="@value"/><xsl:value-of select="@default-value"/></xsl:template>
	<xsl:template match="comment-node" mode="_macro"><xsl:value-of select="@value"/><xsl:value-of select="@default-value"/></xsl:template>
	<xsl:template match="element-ref" mode="_macro">
		<xsl:apply-templates select="*" mode="_macro"/>
	</xsl:template>
	<xsl:template match="macro-include" mode="_macro">
		<xsl:variable name="macro_name" select="@name"/>
		<xsl:apply-templates select="/gmt-macros/macros-def//macro[@name=$macro_name]/*" mode="_macro"/>
	</xsl:template>

	<xsl:template match="gmt-macros | macros-def | structure-def | label | separator | group | macro-ref | @*">
		<xsl:copy>
			<xsl:apply-templates select="*|@*"/>
		</xsl:copy>
	</xsl:template>

	<!-- "rename" constant-def to GMT_constant-def to avoid conflicts when target language has an constant-def element -->
	<xsl:template match="constant-def[@name][@value]">
		<DELTA_constant-def>
			<xsl:apply-templates select="@*"/>
		</DELTA_constant-def>
	</xsl:template>

	<!-- generates a new element named after the value of the name-attributes of this element-ref and continues proccesing -->
	<xsl:template match="element-ref">
		<xsl:element name="{@name}">
			<xsl:for-each select="./attribute-ref">
				<xsl:attribute name="{@name}" select="concat(@value,@default-value)"/>
			</xsl:for-each>
			<xsl:apply-templates select="text-node | comment-node | macro-include | element-ref | GMT-LINK | GMT-LINK_EXT | DELTA-LINK | DELTA-LINK_EXT"/>
		</xsl:element>
	</xsl:template>

	<xsl:template match="text-node">
		<xsl:value-of select="@value"/>
	</xsl:template>
	<xsl:template match="comment-node">
		<xsl:comment><xsl:value-of select="@value"/></xsl:comment>
	</xsl:template>

	<!-- inserts the content of the macro which name-attribute has the same value as the name-attribute of this macro-include -->
	<xsl:template match="/gmt-macros/macros-def//macro//macro-include">
		<xsl:variable name="macro_name" select="@name"/>
		<xsl:apply-templates select="/gmt-macros/macros-def//macro[@name=$macro_name]/*"/>
	</xsl:template>

	<xsl:template match="group-include">
		<xsl:variable name="group_name" select="@name"/>
		<xsl:if test="//group[@name=$group_name]">
			<group name="{@name}" ref="true">
				<xsl:apply-templates select="//group[@name=$group_name]/*"/>
			</group>
		</xsl:if>
	</xsl:template>
	<xsl:template match="group-include[@label]">
		<xsl:variable name="group_name" select="@name"/>
		<xsl:if test="//group[@name=$group_name]">
			<group name="{@label}" ref="true">
				<xsl:apply-templates select="//group[@name=$group_name]/*"/>
			</group>
		</xsl:if>
	</xsl:template>

	<xsl:template match="group-link">
		<xsl:variable name="group_name" select="@name"/>
		<xsl:if test="//group[@name=$group_name]">
			<xsl:copy>
				<xsl:apply-templates select="@*"/>
			</xsl:copy>
		</xsl:if>
	</xsl:template>

	<xsl:template match="single-element-ref">
		<element name="{@name}" standalone="{@standalone}">
			<xsl:element name="{@name}"/>
		</element>
	</xsl:template>

	<xsl:template match="/gmt-macros/structure-def//macros-group-include">
		<xsl:for-each select="/gmt-macros/macros-def//macros-group[@name=current()/@name]/macro">
			<macro-ref name="{@name}"/>
		</xsl:for-each>
	</xsl:template>

	<!-- <xsl:template match="attribute-ref">
		<xsl:copy>
			<xsl:apply-templates select="@*"/>
		</xsl:copy>
	</xsl:template> -->

    <xsl:template match="//text()"/>
</xsl:stylesheet>
