<?xml version="1.0"?>
<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:saxon="http://saxon.sf.net/">
	<xsl:output method="html"/>
	<xsl:strip-space elements="*"/>

	<xsl:param name="element_color">#900090</xsl:param>
	<xsl:param name="attr_name_color">#900000</xsl:param>
	<xsl:param name="attr_value_color">#800080</xsl:param>
	<xsl:param name="text_color">#000000</xsl:param>
	<xsl:param name="comment_color">#808080</xsl:param>
	<xsl:param name="pi_color">#008080</xsl:param>
	<xsl:param name="symbol_color">#0000FF</xsl:param>
	
	<xsl:template match="/">
		<html>
			<head>
				<style type="text/css">
					<xsl:comment>
                    	dl { margin-left:20px; margin-top:-3px; margin-bottom:-3px; }
                    	dl.root { margin-left:5px; margin-top:-3px; margin-bottom:-3px; }
                    	dt { white-space:nowrap; }
                    	.element { color:<xsl:value-of select="$element_color"/>; font-weight:bold }
                    	.attr_name { color:<xsl:value-of select="$attr_name_color"/> }
                    	.attr_value { color:<xsl:value-of select="$attr_value_color"/>; font-style:italic }
                    	.text { color:<xsl:value-of select="$text_color"/> }
                    	.comment { color:<xsl:value-of select="$comment_color"/> }
                    	.pi { color:<xsl:value-of select="$pi_color"/> }
                    	.symbol { color:<xsl:value-of select="$symbol_color"/> }
					</xsl:comment>
				</style>
			</head>
			<body> <!--bgcolor="#F0F0F0"-->
				<dl class="root">
					<xsl:apply-templates/>
				</dl>
			</body>
		</html>
	</xsl:template>   
	<!-- template for text nodes -->
	<xsl:template match="text()">
		<dt>
			<font class="text">
				<xsl:value-of select="."/>
			</font>
		</dt>
	</xsl:template>    
	<!-- template for comment nodes -->
	<xsl:template match="comment()">
		<dt>
			<font class="comment">&lt;!--
				<xsl:value-of select="."/>--&gt;
			</font>
		</dt>
	</xsl:template>    
	<!-- template for processing-instruction nodes -->
	<xsl:template match="processing-instruction()">
		<dt>
			<font class="symbol">&lt;?</font>
			<font class="element">
				<xsl:value-of select="name(.)"/>
			</font>
			<xsl:text> </xsl:text>
			<font class="pi">
				<xsl:value-of select="."/>
			</font>
			<font class="symbol">?&gt;</font>
		</dt>
	</xsl:template>    
	<!-- template for attributes -->
	<xsl:template match="@*">&#160;
		<font class="attr_name">
			<xsl:value-of select="name(.)"/>
		</font>
		<font class="symbol">="</font>
		<font class="attr_value">
			<xsl:value-of select="."/>
		</font>
		<font class="symbol">"</font>
	</xsl:template>    
	<!-- template for elements with element children -->
	<xsl:template match="*[* or text() or comment() or processing-instruction()]">
		<dt>
            <a name="{saxon:path()}"/>
			<font class="symbol">&lt;</font>
			<font class="element">
				<xsl:value-of select="name(.)"/>
			</font>
			<xsl:apply-templates select="@*"/>
			<font class="symbol">&gt;</font>
		</dt>
		<dl>
			<xsl:apply-templates select="* | text() | comment() | processing-instruction()"/>
		</dl>
		<dt>
			<font class="symbol">&lt;/</font>
			<font class="element">
				<xsl:value-of select="name(.)"/>
			</font>
			<font class="symbol">&gt;</font>
		</dt>
	</xsl:template>    
	<!-- template for elements not handled elsewhere (leaf nodes) -->
	<xsl:template match="*">
		<dt>
            <a name="{saxon:path()}"/>
			<font class="symbol">&lt;</font>
			<font class="element">
				<xsl:value-of select="name(.)"/>
			</font>
			<xsl:apply-templates select="@*"/>
			<font class="symbol">/&gt;</font>
		</dt>
	</xsl:template>
</xsl:stylesheet>