<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:saxon="http://saxon.sf.net/" xmlns:file="java:java.io.File">
	<xsl:output method="html" indent="yes"/>
	
	<!-- match root node -->
	<xsl:template match="/">
		<xsl:variable name="file-name" select="file:getName(file:new(string(base-uri())))"/>
		<html>
			<head>
				<title>Asbru Summary Report of <xsl:value-of select="$file-name"/></title>
				<style type="text/css">
					<xsl:comment>
						a { text-decoration:none; font-weight:normal; white-space:nowrap; }
						ul { margin-top:-1; margin-bottom:-1;}
						ol { margin-top:-1; margin-bottom:-1;}
					</xsl:comment>
				</style>
			</head>
			<body>
				<h2>Summary Report of Asbru file <code><xsl:value-of select="$file-name"/></code></h2>
				<ul>
					<li><a href="#Plans">Plans</a></li>
					<li><a href="#Parameters">Parameters</a></li>
					<li><a href="#Variables">Variables</a></li>
					<li><a href="#Constants">Constants</a></li>
					<!-- <li><a href="#Types">Types / Units</a></li>
					<li><a href="#Contexts">Contexts</a></li> -->
				</ul>
				<br/><hr/><br/>
				
				<a name="Plans"><b><big>Plans (<xsl:value-of select="count(//plan)"/>): </big></b></a>
				<xsl:variable name="plan-groups" select="/plan-library/plans/plan-group"/>
				<xsl:choose>
					<xsl:when test="$plan-groups">
					<ul>
						<xsl:apply-templates select="$plan-groups"/>
					</ul>					
					</xsl:when>
					<xsl:otherwise><b>no</b> plans defined</xsl:otherwise>
				</xsl:choose>
				
				<hr/>
				<a name="Parameters"><b><big>Parameters (<xsl:value-of select="count(//parameter-def)"/>): </big></b></a>
				<xsl:variable name="parameter-groups" select="/plan-library/domain-defs/domain/parameter-group"/>
				<xsl:choose>
					<xsl:when test="$parameter-groups">
						<ul>
							<xsl:apply-templates select="$parameter-groups"/>
						</ul>						
					</xsl:when>
					<xsl:otherwise><b>no</b> parameters defined</xsl:otherwise>
				</xsl:choose>
				<hr/>
				
				<xsl:variable name="variables" select="//variable-def"/>
				<a name="Variables"><b><big>Variables (<xsl:value-of select="count($variables)"/>): </big></b></a>
				<xsl:choose>
					<xsl:when test="$variables">
						<ul>
						<xsl:for-each select="$variables">
							<xsl:sort select="@name"/>
							<xsl:variable name="local" select="boolean(current()[ancestor::value-defs])"/>
							<li><a href="{saxon:path()}"><xsl:value-of select="@name"/></a>
							<xsl:choose>
								<xsl:when test="$local"> (local in <i>plan </i><a><xsl:attribute name="href"><xsl:apply-templates select="ancestor::plan" mode="xpath"/></xsl:attribute><xsl:value-of select="ancestor::plan/@name"/></a>) </xsl:when>
								<xsl:otherwise> (global) </xsl:otherwise>
							</xsl:choose>
							<xsl:variable name="variable-refs" select="if ($local) then (ancestor::plan//return-value-assignment[@variable-name=current()/@name])|(ancestor::plan//variable-assignment[@variable=current()/@name])|(ancestor::plan//(variable-ref|is-known-variable|is-unknown-variable)[@name=current()/@name]) else (//return-value-assignment[@variable-name=current()/@name])|(//variable-assignment[@variable=current()/@name])|(//(variable-ref|is-known-variable|is-unknown-variable)[@name=current()/@name])"/>
							<xsl:choose>
								<xsl:when test="$variable-refs"> referenced by
									<ol>
									<xsl:apply-templates select="$variable-refs" mode="info">
										<xsl:sort select="@name"/>
									</xsl:apply-templates>
									</ol>
								</xsl:when>
								<xsl:otherwise><b> not</b> used</xsl:otherwise>
							</xsl:choose>
							</li>
						</xsl:for-each>
						</ul>						
					</xsl:when>
					<xsl:otherwise><b>no</b> variables defined</xsl:otherwise>
				</xsl:choose>
				<hr/>
		
				<xsl:variable name="constants" select="//constant-def"/>
				<a name="Constants"><b><big>Constants (<xsl:value-of select="count($constants)"/>): </big></b></a>
				<xsl:choose>
					<xsl:when test="$constants">
						<ul>
						<xsl:for-each select="$constants">
							<xsl:sort select="@name"/>
							<li><a href="{saxon:path()}"><xsl:value-of select="@name"/></a>
							<xsl:variable name="constant-refs" select="//constant-ref[@name=current()/@name]"/>
							<xsl:choose>
								<xsl:when test="$constant-refs"> referenced by
									<ol>
									<xsl:apply-templates select="$constant-refs" mode="info">
										<xsl:sort select="@name"/>
									</xsl:apply-templates>
									</ol>
								</xsl:when>
								<xsl:otherwise><b> not</b> used</xsl:otherwise>
							</xsl:choose>
							</li>
						</xsl:for-each>
						</ul>						
					</xsl:when>
					<xsl:otherwise><b>no</b> constants defined</xsl:otherwise>
				</xsl:choose>
			</body>
		</html>
	</xsl:template>
	
	<xsl:template match="*" mode="info">
		<li><a href="{saxon:path()}"><xsl:value-of select="node-name()"/></a>, inside
		<xsl:choose>
			<xsl:when test="ancestor::parameter-def">
				<i>parameter-def </i><a><xsl:attribute name="href"><xsl:apply-templates select="ancestor::parameter-def" mode="xpath"/></xsl:attribute><xsl:value-of select="ancestor::parameter-def/@name"/></a>
			</xsl:when>
			<xsl:when test="ancestor::domain">				
				<i><a><xsl:attribute name="href"><xsl:apply-templates select="ancestor::domain" mode="xpath"/></xsl:attribute>domain</a></i>
			</xsl:when>
			<xsl:when test="ancestor::plan">
				<xsl:choose>
					<xsl:when test="ancestor::conditions">
						<code>condition </code><a><xsl:attribute name="href"><xsl:apply-templates select="ancestor::conditions/*[1]" mode="xpath"/></xsl:attribute><xsl:value-of select="node-name(ancestor::conditions/*[1])"/></a><xsl:text>, in </xsl:text>
					</xsl:when>
					<xsl:when test="ancestor::intentions">
						<code><a><xsl:attribute name="href"><xsl:apply-templates select="ancestor::intention" mode="xpath"/></xsl:attribute>intention</a></code><xsl:text>, in </xsl:text>
					</xsl:when>
				</xsl:choose>
				<code>plan </code><a><xsl:attribute name="href"><xsl:apply-templates select="ancestor::plan" mode="xpath"/></xsl:attribute><xsl:value-of select="ancestor::plan/@name"/></a></xsl:when>
			<xsl:when test="ancestor::library-defs"><i>library-defs</i></xsl:when>
		</xsl:choose>
		</li>
	</xsl:template>
	
	<xsl:template match="*" mode="xpath">
		<xsl:value-of select="saxon:path()"/>
	</xsl:template>
	
	<xsl:template match="plan-group">
		<li><code>plan-group</code> (<xsl:value-of select="count(.//plan)"/>)
		<xsl:if test="@title"><xsl:text> "</xsl:text><i><xsl:value-of select="@title"/></i>"</xsl:if>
		<xsl:text>: </xsl:text>
		<xsl:choose>
			<xsl:when test="child::*">
				<ul>
					<xsl:apply-templates>
						<xsl:sort select="@name"/>
					</xsl:apply-templates>
				</ul>
			</xsl:when>
			<xsl:otherwise>no content</xsl:otherwise>
		</xsl:choose>
		</li>
	</xsl:template>
	<xsl:template match="plan">
		<li>
			<a href="{saxon:path()}"><xsl:value-of select="@name"/></a>
			<xsl:variable name="plan-refs" select="//plan-schema[@name=current()/@name]|(//static-plan-pointer|//refers-to)[@plan-name=current()/@name]"/>
			<xsl:choose>
				<xsl:when test="$plan-refs"> referenced by
					<ol>
					<xsl:apply-templates select="$plan-refs" mode="info">
						<xsl:sort select="@name"/>
					</xsl:apply-templates>
					</ol>
				</xsl:when>
				<xsl:otherwise><b> not</b> used</xsl:otherwise>
			</xsl:choose>
		</li>
	</xsl:template>
	
	<xsl:template match="parameter-group">
		<li><code>parameter-group</code> (<xsl:value-of select="count(.//parameter-def)"/>)
		<xsl:if test="@title"><xsl:text> "</xsl:text><i><xsl:value-of select="@title"/></i>"</xsl:if>
		<xsl:text>: </xsl:text>
		<xsl:choose>
			<xsl:when test="child::*">
				<ul>
					<xsl:apply-templates>
						<xsl:sort select="@name"/>
					</xsl:apply-templates>
				</ul>
			</xsl:when>
			<xsl:otherwise>no content</xsl:otherwise>
		</xsl:choose>
		</li>
	</xsl:template>
	<xsl:template match="parameter-def">
		<li><a href="{saxon:path()}"><xsl:value-of select="@name"/></a>
			<xsl:variable name="parameter-refs" select="//parameter-proposition[@parameter-name=current()/@name]|(//parameter-ref|one-of)[@name=current()/@name]|//plan-effect[@parameter=current()/@name]"/>
			<xsl:choose>
				<xsl:when test="$parameter-refs"> referenced by
					<ol>
					<xsl:apply-templates select="$parameter-refs" mode="info">
						<xsl:sort select="@name"/>
					</xsl:apply-templates>
					</ol>
				</xsl:when>
				<xsl:otherwise><b> not</b> used</xsl:otherwise>
			</xsl:choose>
		</li>
	</xsl:template>
</xsl:stylesheet>
