<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:saxon="http://saxon.sf.net/" xmlns:file="java:java.io.File">
	<xsl:output method="html" indent="yes"/>
	
	<!-- match root node -->
	<xsl:template match="/">
		<xsl:variable name="file-name" select="file:getName(file:new(string(base-uri())))"/>
		<html>
			<head>
				<title>Asbru Summary Report of <xsl:value-of select="$file-name"/></title>
				<style type="text/css">
					<xsl:comment>
						a { text-decoration:none; font-weight:normal; white-space:nowrap; }
						ul { margin-top:-1; margin-bottom:-1;}
						ol { margin-top:-1; margin-bottom:-1;}
					</xsl:comment>
				</style>
			</head>
			<body>
				<h2>Summary Report of Asbru file <code><xsl:value-of select="$file-name"/></code></h2>
				<ul>
					<li><a href="#Plans">Plans</a></li>
					<li><a href="#Parameters">Parameters</a></li>
					<li><a href="#Variables">Variables</a></li>
					<li><a href="#Constants">Constants</a></li>
					<!-- <li><a href="#Types">Types / Units</a></li>
					<li><a href="#Contexts">Contexts</a></li> -->
				</ul>
				<br/><hr/><br/>
				
				<a name="Plans"><b><big>Plans (<xsl:value-of select="count(//plan)"/>): </big></b></a>
				<xsl:variable name="plan-groups" select="/plan-library/plans/plan-group"/>
				<xsl:choose>
					<xsl:when test="$plan-groups">
					<ul>
						<xsl:apply-templates select="$plan-groups"/>
					</ul>					
					</xsl:when>
					<xsl:otherwise><b>no</b> plans defined</xsl:otherwise>
				</xsl:choose>
				
				<hr/>
				<a name="Parameters"><b><big>Parameters (<xsl:value-of select="count(//parameter-def)"/>): </big></b></a>
				<xsl:variable name="parameter-groups" select="/plan-library/domain-defs/domain/parameter-group"/>
				<xsl:choose>
					<xsl:when test="$parameter-groups">
						<ul>
							<xsl:apply-templates select="$parameter-groups"/>
						</ul>						
					</xsl:when>
					<xsl:otherwise><b>no</b> parameters defined</xsl:otherwise>
				</xsl:choose>
				<hr/>
				
				<xsl:variable name="variables" select="//variable-def"/>
				<a name="Variables"><b><big>Variables (<xsl:value-of select="count($variables)"/>): </big></b></a>
				<xsl:choose>
					<xsl:when test="$variables">
						<ul>
						<xsl:for-each select="$variables">
							<xsl:sort select="@name"/>
							<xsl:variable name="local" select="boolean(current()[ancestor::value-defs])"/>
							<li><a href="{saxon:path()}"><xsl:value-of select="@name"/></a>
							<xsl:choose>
								<xsl:when test="$local"> (local in <i>plan </i><a><xsl:attribute name="href"><xsl:apply-templates select="ancestor::plan" mode="xpath"/></xsl:attribute><xsl:value-of select="ancestor::plan/@name"/></a>) </xsl:when>
								<xsl:otherwise> (global) </xsl:otherwise>
							</xsl:choose>					
							</li>
						</xsl:for-each>
						</ul>						
					</xsl:when>
					<xsl:otherwise><b>no</b> variables defined</xsl:otherwise>
				</xsl:choose>
				<hr/>
		
				<xsl:variable name="constants" select="//constant-def"/>
				<a name="Constants"><b><big>Constants (<xsl:value-of select="count($constants)"/>): </big></b></a>
				<xsl:choose>
					<xsl:when test="$constants">
						<ul>
						<xsl:for-each select="$constants">
							<xsl:sort select="@name"/>
							<li><a href="{saxon:path()}"><xsl:value-of select="@name"/></a></li>
						</xsl:for-each>
						</ul>						
					</xsl:when>
					<xsl:otherwise><b>no</b> constants defined</xsl:otherwise>
				</xsl:choose>
			</body>
		</html>
	</xsl:template>
	
	<xsl:template match="*" mode="xpath">
		<xsl:value-of select="saxon:path()"/>
	</xsl:template>
	
	<xsl:template match="plan-group">
		<li><code>plan-group</code> (<xsl:value-of select="count(.//plan)"/>)
		<xsl:if test="@title"><xsl:text> "</xsl:text><i><xsl:value-of select="@title"/></i>"</xsl:if>
		<xsl:text>: </xsl:text>
		<xsl:choose>
			<xsl:when test="child::*">
				<ul>
					<xsl:apply-templates>
						<xsl:sort select="@name"/>
					</xsl:apply-templates>
				</ul>
			</xsl:when>
			<xsl:otherwise>no content</xsl:otherwise>
		</xsl:choose>
		</li>
	</xsl:template>
	<xsl:template match="plan">
		<li><a href="{saxon:path()}"><xsl:value-of select="@name"/></a> (<xsl:value-of select="node-name(plan-body/*[last()])"/>)</li>
	</xsl:template>
	
	<xsl:template match="parameter-group">
		<li><code>parameter-group</code> (<xsl:value-of select="count(.//parameter-def)"/>)
		<xsl:if test="@title"><xsl:text> "</xsl:text><i><xsl:value-of select="@title"/></i>"</xsl:if>
		<xsl:text>: </xsl:text>
		<xsl:choose>
			<xsl:when test="child::*">
				<ul>
					<xsl:apply-templates>
						<xsl:sort select="@name"/>
					</xsl:apply-templates>
				</ul>
			</xsl:when>
			<xsl:otherwise>no content</xsl:otherwise>
		</xsl:choose>
		</li>
	</xsl:template>
	<xsl:template match="parameter-def">
		<li><a href="{saxon:path()}"><xsl:value-of select="@name"/></a> (<xsl:value-of select="node-name(*[last()])"/>)</li>
	</xsl:template>
</xsl:stylesheet>
