<?xml version="1.0"?>
<xsl:stylesheet version="2.0"
		xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:output method="text"/>

	<xsl:template match="value-description">
		<xsl:value-of select="@type"/><xsl:text> </xsl:text><xsl:apply-templates/>
	</xsl:template>

	<xsl:template match="comparison">
		<xsl:apply-templates select="left-hand-side"/><xsl:text> </xsl:text><xsl:value-of select="@type"/><xsl:text> </xsl:text><xsl:apply-templates select="right-hand-side"/>
	</xsl:template>
	
	<xsl:template match="numerical-constant">
		<xsl:value-of select="@value"/>
	</xsl:template>

	<xsl:template match="plan">
		&quot;<xsl:value-of select="@name"/>&quot;: <xsl:apply-templates select="plan-body"/>
	</xsl:template>
	
	<xsl:template match="plan-body">
		<xsl:value-of select="node-name(*)"/>
	</xsl:template>
	
	<xsl:template match="parameter-def">
		&quot;<xsl:value-of select="@name"/>&quot;: <xsl:value-of select="node-name(*)"/>
	</xsl:template>

	<xsl:template match="parameter-proposition">
		<xsl:text>("</xsl:text><xsl:value-of select="@parameter-name"/><xsl:text>" </xsl:text><xsl:apply-templates select="is-known-parameter|is-unknown-parameter|value-description|value-range"/>); <xsl:apply-templates select="context/*"/>; [<xsl:apply-templates select="time-annotation/*"/>]
	</xsl:template>

	<xsl:template match="parameter-ref | is-known-parameter|is-unknown-parametervariable-ref | plan-schema">
		<xsl:text>"</xsl:text><xsl:value-of select="@name"/>&quot;
	</xsl:template>
	<xsl:template match="static-plan-pointer">
		<xsl:text>"</xsl:text><xsl:value-of select="@plan-name"/>&quot;
	</xsl:template>
	<xsl:template match="qualitative-constant">
		<xsl:text>'</xsl:text><xsl:value-of select="@value"/>&apos;
	</xsl:template>
	<xsl:template match="constant-ref|variable-ref">
		<xsl:text>'</xsl:text><xsl:value-of select="@name"/>&apos;
	</xsl:template>

	<xsl:template match="variable-assignment">
		<xsl:text>"</xsl:text><xsl:value-of select="@variable"/><xsl:text>" = </xsl:text><xsl:apply-templates/>
	</xsl:template>

	<xsl:template match="if-then-else">
		<xsl:text>(</xsl:text><xsl:apply-templates select="simple-condition"/><xsl:text>) ? </xsl:text><xsl:apply-templates select="then-branch"/><xsl:if test="else-branch"><xsl:text> : </xsl:text><xsl:apply-templates select="else-branch"/></xsl:if>
	</xsl:template>

	<xsl:template match="subplans | then-branch | else-branch | conditions">
		<xsl:choose>
			<xsl:when test="count(*) = 1 and not (string(node-name()) = 'conditions')"><xsl:apply-templates select="*"/></xsl:when>
			<xsl:otherwise>
				<xsl:for-each select="* except (delta-link,comment,explanation,url,bibref)">
					<xsl:value-of select="node-name()"/><xsl:if test="position() != last()"><xsl:text>; </xsl:text></xsl:if>
				</xsl:for-each>
			</xsl:otherwise>
		</xsl:choose>	
	</xsl:template>

	<xsl:template match="simple-condition-combination|constraint-combination|wait-for-group|abort-if-group">
		<xsl:variable name="type" select="@type"/>
		<xsl:choose>
			<xsl:when test="count(*) = 1"><xsl:apply-templates select="*"/></xsl:when>
			<xsl:otherwise>
				<xsl:for-each select="*">
					(<xsl:apply-templates select="current()"/>)<xsl:if test="position() != last()"><xsl:text> </xsl:text><xsl:value-of select="$type"/><xsl:text> </xsl:text></xsl:if>
				</xsl:for-each>
			</xsl:otherwise>
		</xsl:choose>	
	</xsl:template>

	<xsl:template match="user-performed|any|all|always|now|one|none|self"><xsl:value-of select="node-name()"/></xsl:template>

	<xsl:template match="time-range">
		[<xsl:choose>
			<xsl:when test="starting-shift/earliest"><xsl:apply-templates select="starting-shift/earliest/*"/></xsl:when>
			<xsl:otherwise>_</xsl:otherwise>
		</xsl:choose><xsl:text>, </xsl:text>
		<xsl:choose>
			<xsl:when test="starting-shift/latest"><xsl:apply-templates select="starting-shift/latest/*"/></xsl:when>
			<xsl:otherwise>_</xsl:otherwise>
		</xsl:choose><xsl:text>], </xsl:text>
		[<xsl:choose>
			<xsl:when test="finishing-shift/earliest"><xsl:apply-templates select="finishing-shift/earliest/*"/></xsl:when>
			<xsl:otherwise>_</xsl:otherwise>
		</xsl:choose><xsl:text>, </xsl:text>
		<xsl:choose>
			<xsl:when test="finishing-shift/latest"><xsl:apply-templates select="finishing-shift/latest/*"/></xsl:when>
			<xsl:otherwise>_</xsl:otherwise>
		</xsl:choose><xsl:text>], </xsl:text>
		[<xsl:choose>
			<xsl:when test="duration/minimum"><xsl:apply-templates select="duration/minimum/*"/></xsl:when>
			<xsl:otherwise>_</xsl:otherwise>
		</xsl:choose><xsl:text>, </xsl:text>
		<xsl:choose>
			<xsl:when test="duration/maximum"><xsl:apply-templates select="duration/maximum/*"/></xsl:when>
			<xsl:otherwise>_</xsl:otherwise>
		</xsl:choose><xsl:text>], </xsl:text>
		<!-- <xsl:apply-templates select="following-sibling::*[1]"/> -->
	</xsl:template>

    <!-- todo -->
	<xsl:template match="ask">
		<xsl:apply-templates select="*"/>
	</xsl:template>

	<xsl:template match="*">
		<xsl:apply-templates select="*"/>
	</xsl:template>

	<xsl:template match="text()"/>
</xsl:stylesheet>
