<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:saxon="http://saxon.sf.net/" xmlns:file="java:java.io.File">
	<xsl:output method="html" indent="yes"/>

	<xsl:variable name="CONST_ALPHABET">ABCDEFGHIJKLMNOPQRSTUVWXYZ</xsl:variable>

	<!-- match root node -->
	<xsl:template match="/">
		<xsl:variable name="file-name" select="file:getName(file:new(string(base-uri())))"/>
		<html>
			<head>
				<title>Usage of elements in file <xsl:value-of select="$file-name"/></title>
				<style type="text/css">
					<xsl:comment>
						a { text-decoration:none; font-weight:normal; white-space:nowrap; }
						ul { margin-top:-1; margin-bottom:-1;}
					</xsl:comment>
				</style>
			</head>
			<body>
				<h2>Usage of elements in file <i><xsl:value-of select="$file-name"/></i></h2>
				<xsl:variable name="all-elements" select="//*"/>
				<b><xsl:value-of select="count(distinct-values(for $n in $all-elements return string(node-name($n))))"/> unique elements with <xsl:value-of select="count($all-elements)"/> total occurrences found</b>:
				<ul>
				<xsl:call-template name="output-element-index"/>
				</ul>
				<br/>
				<hr size="5"/>
				<br/>
				<ul>
				<xsl:for-each-group select="$all-elements" group-by="node-name()">
					<xsl:sort select="count(current-group())" order="descending"/>
					<xsl:sort select="string(node-name())"/>
					<li><a name="{node-name()}">
					<b><xsl:value-of select="node-name()"/></b>: <b><xsl:value-of select="count(current-group())"/></b> occurrences
					<ul><li><xsl:apply-templates select="current-group()" mode="element"/></li></ul>
					</a></li>
				</xsl:for-each-group>
				</ul>
			</body>
		</html>
	</xsl:template>

	<xsl:template match="*" mode="element">
		<a href="{saxon:path()}"><xsl:value-of select="node-name()"/> #<xsl:value-of select="position()"/></a><xsl:if test="position()!=last()">
						<xsl:text>, </xsl:text></xsl:if>
	</xsl:template>

	<xsl:template name="output-element-index">
		<xsl:param name="alphabet" select="$CONST_ALPHABET"/>
		<xsl:if test="$alphabet">
			<xsl:call-template name="output-elements-by-letter">
				<xsl:with-param name="letter" select="substring($alphabet, 1, 1)" />
			</xsl:call-template>
			<xsl:call-template name="output-element-index">
				<xsl:with-param name="alphabet" select="substring($alphabet, 2)" />
			</xsl:call-template>
		</xsl:if>
	</xsl:template>

	<xsl:template name="output-elements-by-letter">
		<xsl:param name="letter" select="'A'" />
		<xsl:variable name="element-set" select="//*[upper-case(substring(string(node-name()), 1, 1))=$letter]"/>
		<xsl:if test="$element-set">
			<li><b><xsl:value-of select="$letter"/></b> (<xsl:value-of select="count(distinct-values(for $n in $element-set return string(node-name($n))))"/> / <xsl:value-of select="count($element-set)"/> elements):
				<xsl:for-each-group select="$element-set" group-by="node-name()">
					<xsl:sort select="string(node-name())"/>
							<a href="#{node-name()}"><b><xsl:value-of select="node-name()"/></b></a>
					<xsl:if test="position()!=last()">
						<xsl:text>, </xsl:text></xsl:if>
				</xsl:for-each-group>
			</li> 
		</xsl:if>			
	</xsl:template>
</xsl:stylesheet>
